import { meta } from "./assets/meta/index.js"

export default {
  // Global page headers: https://go.nuxtjs.dev/config-head
  head: {
    title: 'compdfkit_web_cn',
    htmlAttrs: {
      lang: 'en',
    },
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { hid: 'description', name: 'description', content: '' },
      { name: 'format-detection', content: 'telephone=no' },
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
    ],
  },

  // Global CSS: https://go.nuxtjs.dev/config-css
  css: [
    'element-ui/lib/theme-chalk/index.css',
    {
      src: '~/assets/css/common.css'
    }
  ],

  // Plugins to run before rendering page: https://go.nuxtjs.dev/config-plugins
  plugins: [
    '@/plugins/element-ui',
  ],

  // Auto import components: https://go.nuxtjs.dev/config-components
  components: [
    {
      path: '~/components/',
      ignore: ["**/*.js"]
    }
  ],

  // Modules for dev and build (recommended): https://go.nuxtjs.dev/config-modules
  buildModules: [,
    '@nuxtjs/svg',
    'nuxt-windicss'
    // https://go.nuxtjs.dev/eslint
  ],

  // Modules: https://go.nuxtjs.dev/config-modules
  modules: [
    // https://go.nuxtjs.dev/axios
    '@nuxtjs/axios',
    // '@unocss/nuxt'
  ],

  // Axios module configuration: https://go.nuxtjs.dev/config-axios
  axios: {
    // Workaround to avoid enforcing hard-coded localhost:3000: https://github.com/nuxt-community/axios-module/issues/308
    baseURL: '/',
  },

  // Build Configuration: https://go.nuxtjs.dev/config-build
  build: {
    transpile: [/^element-ui/],
  },

  publicRuntimeConfig: {
    meta,
    MODE_ENV: process.env.MODE_ENV,
    storeHost: process.env.MODE_ENV === 'production' ? 'https://store.pdfreaderpro.com' : 'http://test-store.kdan.cn:3018',
    pdfDomain: process.env.MODE_ENV === 'production' ? 'https://content.pdfreaderpro.com' : 'https://test-pdf-pro.kdan.cn:3020',
    pdfproHost: process.env.MODE_ENV === 'production' ? 'https://www.pdfreaderpro.com' : 'http://test-pdf-pro.kdan.cn:3021'
  },
  env: {
    domain: process.env.MODE_ENV === 'production' ? 'https://www.compdf.com' : 'http://test-pdf-pro.kdan.cn:3026',
    webhost: process.env.MODE_ENV === 'production' ? 'https://content.pdfreaderpro.com' : 'https://test-pdf-pro.kdan.cn:3020'
  }
}
